<?php

namespace Drupal\commerce_payment_example\PluginForm\OffsiteRedirect;

use Drupal\commerce_payment\Exception\PaymentGatewayException;
use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm as BasePaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\commerce_order\Entity\Order;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\user\Entity\User;

class PaymentOffsiteForm extends BasePaymentOffsiteForm {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    /** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();
    $order_id = \Drupal::routeMatch()->getParameter('commerce_order')->id();
    $order = Order::load($order_id);
    $address = $order->getBillingProfile()->address->first();
    $userCurrent = \Drupal::currentUser();
    $user = User::load($userCurrent->id());
    $name = $user->getUsername();
    $date = new DrupalDateTime();

    $redirect_method = $payment_gateway_plugin->getConfiguration()['redirect_method'];
   
    // $payment_method = $payment_gateway_plugin->getConfiguration()['payment_method'];
    
    $cancel_url = $payment_gateway_plugin->getConfiguration()['cancel_url'];
    $return_url = $payment_gateway_plugin->getConfiguration()['return_url'];
    $remove_js = ($redirect_method == 'post_manual');
    $redirect_url='';
    if (in_array($redirect_method, ['post', 'post_manual'])) {
      $redirect_url = 'http://hadepay.pinesucceed.com:880/payWithHadePay';
      $redirect_method = 'post';   
    } 
    else {
      // Gateways that use the GET redirect method usually perform an API call
      // that prepares the remote payment and provides the actual url to
      // redirect to. Any params received from that API call that need to be
      // persisted until later payment creation can be saved in $order->data.
      // Example: $order->setData('my_gateway', ['test' => '123']), followed
      // by an $order->save().
      $order = $payment->getOrder();

      // Simulate an API call failing and throwing an exception, for test purposes.
      // See PaymentCheckoutTest::testFailedCheckoutWithOffsiteRedirectGet().
      if ($order->getBillingProfile()->get('address')->family_name == 'FAIL') {
        throw new PaymentGatewayException('Could not get the redirect URL.');
      }
      $redirect_url = Url::fromRoute('commerce_payment_example.dummy_redirect_302', [], ['absolute' => TRUE])->toString();
       // $redirect_url = 'http://hadepay.pinesucceed.com:880/payWithHadePay';
       // $redirect_method = 'post';
    }
    $data = [
      'bussineskey' => 'N2MwODRhZTE2ZTE3ZWI3ZTVlYzMwMDY3OGI1ZmYxMjkzNTk1ODZlNThlZDIwZGViNDNhNWMzYjFhOGQzOWUzMjYxMTczMTJlNjkzZWNkYjUzNWE3YjQwM2RmZjAyODM1YjI3OTNkNjYyZTBmODdjZWEwNTQ0NWFiNzdiOTM0NTJwT1dLU0xlS0dpUVIzfnBEbGlPbnJzSGZ+WmVjOUo4Z0VKU2UzNnZUckNqZVI1N3FrWjdPSVhwaXkwMXBzWEV',
      'username'=> $name,
      'order_id' => $order_id ,
      'order_date' => str_replace(" ", "%20", $date->format('d/m/Y h:m:s')),
      'first_name' => str_replace(" ", "%20", $address->getGivenName()),
      'last_name' => str_replace(" ", "%20", $address->getFamilyName()),
      'email' => $order->getEmail(),
      'company' => str_replace(" ", "%20", $address->getOrganization()),
      'street' => str_replace(" ", "%20", $address->getAddressLine1()).','.str_replace(" ", "%20", $address->getAddressLine2()),
      'city' => str_replace(" ", "%20", $address->getLocality()),
      'state' => str_replace(" ", "%20", $address->getAdministrativeArea()),
      'country' => $address->getCountryCode(),
      'zip' => str_replace(" ", "%20", $address->getPostalCode()),
      'ship_street' => '',
      'ship_city' => '',
      'ship_state' => '',
      'ship_country' => '',
      'ship_zip' => '',
      'amount' => round($payment->getAmount()->getNumber(), 2),
      'return' => $return_url,
      'cancel' => $cancel_url,
      'description' =>'Total Amount',
    ];

    $form = $this->buildRedirectForm($form, $form_state, $redirect_url, $data, $redirect_method);
    if ($remove_js) {
      // Disable the javascript that auto-clicks the Submit button.
      unset($form['#attached']['library']);
    }

    return $form;
  }

}
